@@ -41,11 +41,12 @@
 #include <errno.h>
 #ifdef STDC_HEADERS
 #include <stdlib.h>
-#else
-extern int errno;
 #endif
 #include <string.h>
 #include <glib.h>
+#ifdef HAVE_LIBGEN_H
+#include <libgen.h>
+#endif
 
 #if __STDC__
 # define P_(s) s
@@ -217,10 +218,7 @@ char *filesystem_type (char *path, char *relpath, struct stat *statp);
    Return "unknown" if its filesystem type is unknown.  */
 
 char *
-filesystem_type (path, relpath, statp)
-     char *path;
-     char *relpath;
-     struct stat *statp;
+filesystem_type (char *path, char *relpath, struct stat *statp)
 {
   static char *current_fstype = NULL;
   static dev_t current_dev;
@@ -247,10 +245,7 @@ fstype_internal_error (int level, int num, char const *fmt, ...)
    Return "unknown" if its filesystem type is unknown.  */
 
 static char *
-filesystem_type_uncached (path, relpath, statp)
-     char *path;
-     char *relpath;
-     struct stat *statp;
+filesystem_type_uncached (char *path, char *relpath, struct stat *statp)
 {
   char *type = NULL;
 
@@ -401,8 +396,7 @@ filesystem_type_uncached (path, relpath, statp)
    part of CP. */
 
 static int
-xatoi (cp)
-     char *cp;
+xatoi (char *cp)
 {
   int val;
   
